# django_unused2

![Static Analysis](https://github.com/hovi/django_unused2/actions/workflows/.static-analysis.yml/badge.svg)
![Tests](https://github.com/hovi/django_unused2/actions/workflows/.tests-ci.yml/badge.svg)

`django_unused2` is a tool to help identify unused templates and broken template references in Django projects.
It is inspired by [django_unused](https://github.com/edustaff/django-unused/).